@@ -149,7 +149,7 @@ class LabyrinthWindow (gtk.Window):
 		# Deal with loading the map
 		if not filename:
 			self.MainArea.set_size_request (600, 500)
-			self.map_number = MapList.count() +1
+			self.map_number = MapList.next_col_id ()
 			# TODO: This shouldn't be set to a hard-coded number.  Fix.
 			self.pane_pos = 500
 			self.title_cp = _("Untitled Map %d" % self.map_number)
